#!/bin/bash
# called by user to perform the necessary updation
# perform the process of updating the files in the safesquid folder
# ACTION(s) performed : softlink, mkdir, copy with overwite, copy without overwrite
# OWNERSHIP and PERMISSIONS will also be set

CWD=`dirname $0`
IAM=`basename $0`

[ "x${CWD}" == "x." ] && CWD=`pwd`

PARENT_DIR=`dirname ${CWD}`

LIST=${CWD}"/list.conf";
LOGF="/tmp/setup.log";
DATE=`date`;
L=0;


LOG()
{
	echo "${DATE} - ${*}" 
}

MAKE_USER ()
{

		ID=""; 
		unset GID;
		typeset -a GID;
		unset G; typeset -i G; G=1
		USER="ssquid"
		GROUP="root"
		
		while [ 1 ]
		do
			echo -ne "Checking if user ${USER} exists ... "
			ID=`id -un ${USER} 2> /dev/null`
			[ "x${ID}" == "x${USER}" ] && echo -e "Yes!" && GID=( `id -Gn ${USER} 2> /dev/null` )
			[ "x${ID}" != "x${USER}" ] && echo -e "No!"
			
			for grps in ${GID[*]}
			do
				[ "x${grps}" == "x${GROUP}" ] && G=0 &&  echo "user ${USER} is a member of group ${GROUP}" && break;
			
			done
			
			[ "x${G}" == "x0" ] && echo "user ${USER} is already a member of group ${GROUP}" && break;
			
			if [ "x${ID}" != "x${USER}" ] 
			then
				echo -ne "Creating user ${USER} in group ${GROUP}" 
				useradd -r ${USER} -g ${GROUP} --shell ${SHELL}
			else
				echo -ne "user ${USER} exists, simply modifying group membership for ${GROUP}" 
				usermod ${USER} -g ${GROUP}
			fi
			
			G=1;
			GID=( `id -Gn ${USER} 2> /dev/null` )
			for grps in ${GID[*]}
			do
				[ "x${grps}" == "x${GROUP}" ] && G=0 && break;
			
			done
			
			[ "x${G}" == "x0" ] && echo "user ${USER} is now a member of group ${GROUP}" && break;
			
			
			echo " ... failure!" 
			echo "Please Report this the SafeSquid Tech Support"
			echo "Setup canot proceed because creating user:group ${USER}:${GROUP} failed"
			exit;
		done
		
		OWNER="${USER}:${GROUP}"
}

READ_SOURCE()
{
	source ${LIST}
}

MAKE_DIRECTORIES()
{
	for((i=0;i<${#DEST_DIR[*]};i++))
	do	
		if [ ! -d ${DEST_DIR[$i]} ];then
			mkdir -p ${DEST_DIR[$i]}
			[ "x${PERMISSION_DIR[$i]}" == "x" ] && continue
			chown -R ssquid:root "${DEST_DIR[$i]}"
			chmod ${PERMISSION_DIR[$i]} "${DEST_DIR[$i]}"		
		fi
	done

}

COPY_FILES()
{
	for((i=0;i<${#DEST_FILE[*]};i++))
	do
		[ -f "${PARENT_DIR}/${DEST_FILE[$i]}" ] && cp -R "${PARENT_DIR}/${DEST_FILE[$i]}" "${DEST_FILE[$i]}"
		[ "x${PERMISSION_FILE[$i]}" == "x" ] && continue
		[ -f "${DEST_FILE[$i]}" ] || continue
		chown -R ssquid:root "${DEST_FILE[$i]}"
		chmod ${PERMISSION_FILE[$i]} "${DEST_FILE[$i]}"
	done

}

MAKE_LINKS()
{
	for((i=0;i<${#TARGET[*]};i++))
	do	
		ln -fs "${TARGET[$i]}" "${S_LINK[$i]}" 
	done
}

INSTALL_PACKAGES()
{	
	PACKS=`< ${CWD}/dependencies.lst`
	
	if [ "${PACKS}x" != "x" ]; then
		export DEBIAN_FRONTEND=noninteractive
		yum -q -y install net-tools psmisc ${PACKS}
		rpm -ivh http://rpmfind.net/linux/epel/7/x86_64/Packages/h/heimdal-libs-7.5.0-1.el7.x86_64.rpm
		export DEBIAN_FRONTEND=
	fi	
}

MAKE_CHANGES(){

HOSTNM="HOSTNAME\=\"`hostname -f`\""
DOMAIN="DOMAIN\=\"`hostname -d`\""

sed -i "s/HOSTNAME\=\"\"/${HOSTNM}/g"  /opt/safesquid/default/startup.ini
sed -i "s/DOMAIN\=\"\"/${DOMAIN}/g" /opt/safesquid/default/startup.ini

chmod 755 /etc/init.d/tcp_tune.sh

[ -f /opt/safesquid/startup.ini ] && sed -i 's/;/#/g' /opt/safesquid/startup.ini

chown -R ssquid:root /usr/local/safesquid 
chown -R ssquid:root /var/db/safesquid   
chown -R ssquid:root /var/log/safesquid 
chown -R ssquid:root /var/cache/safesquid
chmod 644 /etc/shadow

}

MAIN()
{
	INSTALL_PACKAGES
	MAKE_USER
	READ_SOURCE
	MAKE_DIRECTORIES
	COPY_FILES
	MAKE_LINKS
	MAKE_CHANGES
}


> ${LOGF};
chown ssquid:root ${LOGF}

MAIN 2>&1 | tee -a ${LOGF};
